# eric7.Plugins.VcsPlugins.vcsMercurial.RebaseExtension.rebase

Module implementing the rebase extension interface.

### Global Attributes

None

### Classes

Rebase | Class implementing the rebase extension interface.

### Functions

None

## Rebase

Class implementing the rebase extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Rebase | Constructor
hgRebase | Public method to rebase changesets to a different branch.
hgRebaseAbort | Public method to abort rebasing changesets from another branch.
hgRebaseContinue | Public method to continue rebasing changesets from another branch.

### Static Methods

None

#### Rebase (Constructor)

Rebase(vcs, ui=None)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object
ui (QWidget)
  reference to a UI widget (defaults to None)

#### Rebase.hgRebase

hgRebase()

Public method to rebase changesets to a different branch.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

#### Rebase.hgRebaseAbort

hgRebaseAbort()

Public method to abort rebasing changesets from another branch.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

#### Rebase.hgRebaseContinue

hgRebaseContinue()

Public method to continue rebasing changesets from another branch.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

Up